function lambda_max = comp_lambdamax(Phi,Y)
%comp_lambdamax computes lambdamax, that is the lambda that makes the
%solution theta to 
%min_theta sum_t||Y_t-Phi_t*theta_t||^2 + lambda||(theta_t-theta_t+1)||
%constant.
%
%CALLING SEQUENCES:
% lambda_max = comp_lambdamax(Phi,Y)

% AUTHOR    Henrik Ohlsson <ohlsson@isy.liu.se>
% UPDATE    Dec 1 2009
%
% COPYRIGHT 2009 Henrik Ohlsson, Lennart Ljung and Stephen Boyd

[N n] = size(Phi);
T = zeros(N,n);
Tnorm = zeros(N,1);
sumPhiPhi = 0;

sumYPhi = sum((Y*ones(1,n)).*Phi,1);
for t=1:N
sumPhiPhi=sumPhiPhi + Phi(t,:)'*Phi(t,:);
end
theta_const=sumPhiPhi\sumYPhi';

T(1,:) = 2*(Y(1)-Phi(1,:)*theta_const)*Phi(1,:);
Tnorm(1)=norm(T(1,:));
for t=2:N-1
T(t,:) = T(t-1,:) + 2*(Y(t)-Phi(t,:)*theta_const)*Phi(t,:);
Tnorm(t)=norm(T(t,:));
end

lambda_max = max(Tnorm);